\name{estimate_Q}
\Rdversion{1.1}
\alias{estimate_Q}
\title{
Initial Estimation of Q portion of the Likelihood}
\description{
An internal function called by the \code{tmle} function to obtain an initial estimate of the\code{Q} portion of the likelihood based on user-supplied values for \code{Q(A,W)} and counterfactual outcomes \code{Q(1,W),Q(0,W)}, or a user-supplied regression formula, or based on a model data-adaptively selected by the \code{DSA} algorithm.  If \code{DSA} is not available and \code{Q} is not user-supplied, estimation is based on a main terms regression using \code{glm}.
}
\usage{
estimate_Q(Q, DSAargs, Y, A, W, Delta, family, wts, id)
}
\arguments{
  \item{Q}{a 3-column matrix \code{(Q(A,W), Q(1,W), Q(0,W))}, a user-specified regression formula, or \code{NULL}.  If \code{Q} is \code{NULL} \code{DSA} is used to select a model.  If \code{DSA} is unavailable estimation is based on a main terms regression using \code{glm}}
  \item{DSAargs}{an optional list specifying values for all arguments to the \code{DSA} algorithm}
   \item{Y}{continuous or binary outcome variable}
  \item{A}{binary treatment indicator, \code{1} - treatment, \code{0} - control}
  \item{W}{vector, matrix, or dataframe containing baseline covariates}
  \item{Delta}{indicator of missing outcome or treatment assignment.  \code{1} - observed, \code{0} - missing}
  \item{family}{family specification for regressions, generally \sQuote{gaussian} for continuous oucomes, \sQuote{binomial} for binary outcomes}
  \item{wts}{optional weights on observations. Defaults to unweighted}
  \item{id}{id identifying repeated measures}
}
\value{
  \item{Q}{a matrix with one row per observation, 3 columns containing the initial estimate of \code{Q(A,W)} and predicted values for counterfactual outcomes \code{Q(1,W), Q(0,W)}}
  \item{coef}{coefficients for each term in working model used for initial estimation of \code{Q}}
  \item{type}{type of estimation procedure: \code{NULL}-user supplied,\sQuote{glm}-generalized linear regression using user-specified or main terms model, \sQuote{DSA}-model selected by \code{DSA}}
}

\author{Susan Gruber}

\seealso{
\code{\link{tmle}},
\code{\link{estimate_g}},
\code{\link[DSA]{DSA}}
}
